@@ -87,6 +87,11 @@ class CreateAppGroupRequest(RpcRequest):
 
 	def set_Namespace(self, Namespace):  # String
 		self.add_query_param('Namespace', Namespace)
+	def get_EnableLog(self): # Boolean
+		return self.get_query_params().get('EnableLog')
+
+	def set_EnableLog(self, EnableLog):  # Boolean
+		self.add_query_param('EnableLog', EnableLog)
 	def get_AppKey(self): # String
 		return self.get_query_params().get('AppKey')
 
