@@ -51,3 +51,8 @@ class GetJobInfoRequest(RpcRequest):
 
 	def set_Namespace(self, Namespace):  # String
 		self.add_query_param('Namespace', Namespace)
+	def get_JobName(self): # String
+		return self.get_query_params().get('JobName')
+
+	def set_JobName(self, JobName):  # String
+		self.add_query_param('JobName', JobName)
