@@ -24,10 +24,20 @@ class ListNamespacesRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'schedulerx2', '2019-04-30', 'ListNamespaces')
-		self.set_method('GET')
+		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_NamespaceName(self): # String
+		return self.get_query_params().get('NamespaceName')
+
+	def set_NamespaceName(self, NamespaceName):  # String
+		self.add_query_param('NamespaceName', NamespaceName)
+	def get_Namespace(self): # String
+		return self.get_query_params().get('Namespace')
+
+	def set_Namespace(self, Namespace):  # String
+		self.add_query_param('Namespace', Namespace)
